@@ -60,6 +60,38 @@ class CommunityPermissions(LDPPermissions):
 
         return perms
 
+    def get_container_permissions(self, request, view, obj=None):
+        perms = set({'view'})
+        if obj is None:
+            resolved = resolve(request.path_info)
+            community = None
+            if 'slug' in resolved.kwargs and (resolved.url_name == "community-communitycircle-list" \
+                or resolved.url_name == "community-communityproject-list" \
+                or resolved.url_name == "community-communitymember-list" \
+                or resolved.url_name == "community-communityjoboffer-list" \
+                or resolved.url_name == "community-communityprofile-list" \
+                or resolved.url_name == "community-communityprofile-detail" \
+                or resolved.url_name == "community-detail" \
+                or resolved.url_name == "community-communityaddress-list" \
+                or resolved.url_name == "community-detail"):
+                from djangoldp_community.models import Community
+                community = Community.objects.get(slug=resolved.kwargs['slug'])
+            elif (resolved.url_name == "open-communities-community-list" or resolved.url_name == "community-list") and hasattr(request, 'parent_id'):
+                from djangoldp.models import Model
+                from django.conf import settings
+                community = Model.resolve_parent(request.parent_id.replace(settings.SITE_URL, ''))
+            if community:
+                if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
+                    if community.members.get(user=request.user).is_admin:
+                        perms = perms.union({'add'})
+                if community.allow_self_registration and ('slug' in resolved.kwargs and resolved.url_name == "community-communitymember-list"):
+                    perms = perms.union({'add'})
+
+        else:
+            perms = self.get_object_permissions(request, view, obj)
+
+        return perms
+
 
 class CommunityCirclePermissions(CirclePermissions):
     filter_backends = []
@@ -162,7 +194,8 @@ class CommunityMembersPermissions(CommunityPermissions):
                     perms = perms.union({'add'})
 
         else:
-            return self.get_object_permissions(request, view, obj)
+            perms = self.get_object_permissions(request, view, obj)
+
         return perms
 
 class CommunityProfilePermissions(CommunityPermissions):
